Don't use convertZeroToNull() here as it makes no sense
[mailer.git] / ref.php
diff --git a/ref.php b/ref.php
index 52a353a255f9448faeea0f001a67edfe382c93d4..6b0302c17adcc8514e727398e118e77ec6a63ff3 100644 (file)
--- a/ref.php
+++ b/ref.php
@@ -6,9 +6,9 @@
  * -------------------------------------------------------------------- *
  * File              : ref.php                                          *
  * -------------------------------------------------------------------- *
* Short description : Redirection for the referal link                 *
  * -------------------------------------------------------------------- *
* Kurzbeschreibung  : Weiterleitungsscript fuer die Referal-Links      *
  * -------------------------------------------------------------------- *
  * $Revision::                                                        $ *
  * $Date::                                                            $ *
@@ -16,8 +16,8 @@
  * $Author::                                                          $ *
  * -------------------------------------------------------------------- *
  * Copyright (c) 2003 - 2009 by Roland Haeder                           *
- * Copyright (c) 2009 - 2011 by Mailer Developer Team                   *
- * For more information visit: http://www.mxchange.org                  *
+ * Copyright (c) 2009 - 2012 by Mailer Developer Team                   *
+ * For more information visit: http://mxchange.org                      *
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
  * it under the terms of the GNU General Public License as published by *
 // Load security stuff here
 require('inc/libs/security_functions.php');
 
+// Init start time
+$GLOBALS['__start_time'] = microtime(true);
+
 // Set module
-$GLOBALS['module'] = 'ref';
-$GLOBALS['output_mode'] = -1;
+$GLOBALS['__module']      = 'ref';
+$GLOBALS['__output_mode'] = -1;
 
 // Load the required file(s)
 require('inc/config-global.php');
@@ -51,11 +54,11 @@ setContentType('text/html');
 // No refid by default
 $url = 'modules.php?module=index';
 
-// Check for determined referal id
-if ((isExtensionActive('user')) && (isReferalIdValid()) && (isValidUserId(determineReferalId()))) {
+// Check for determined referral id
+if ((isExtensionActive('user')) && (isReferralIdValid()) && (isValidUserId(determineReferralId()))) {
        // Update ref counter
        SQL_QUERY_ESC("UPDATE `{?_MYSQL_PREFIX?}_user_data` SET `ref_clicks`=`ref_clicks`+1 WHERE `userid`=%s LIMIT 1",
-               array(makeZeroToNull(determineReferalId())), __FILE__, __LINE__);
+               array(determineReferralId()), __FILE__, __LINE__);
 
        // Base URL for redirection
        switch (getConfig('refid_target')) {
@@ -6,9 +6,9 @@
  * File              : ref.php                                          *
  * -------------------------------------------------------------------- *
- * Short description : Redirection for the referal link                 *
+ * Short description : Redirection for the referral link                *
  * -------------------------------------------------------------------- *
@@ -6,9 +6,9 @@
  * -------------------------------------------------------------------- *
- * Kurzbeschreibung  : Weiterleitungsscript fuer die Referal-Links      *
+ * Kurzbeschreibung  : Weiterleitungsscript fuer die Referral-Links     *
  * -------------------------------------------------------------------- *
  * $Revision::                                                        $ *